@@ -10,15 +10,15 @@ import (
 	"time"
 
 	"github.com/golang/glog"
-	"github.com/google/mtail/internal/metrics"
-	"github.com/google/mtail/internal/metrics/datum"
-	"github.com/google/mtail/internal/runtime/code"
-	"github.com/google/mtail/internal/runtime/compiler/ast"
-	"github.com/google/mtail/internal/runtime/compiler/errors"
-	"github.com/google/mtail/internal/runtime/compiler/parser"
-	"github.com/google/mtail/internal/runtime/compiler/position"
-	"github.com/google/mtail/internal/runtime/compiler/symbol"
-	"github.com/google/mtail/internal/runtime/compiler/types"
+	"github.com/jaqx0r/mtail/internal/metrics"
+	"github.com/jaqx0r/mtail/internal/metrics/datum"
+	"github.com/jaqx0r/mtail/internal/runtime/code"
+	"github.com/jaqx0r/mtail/internal/runtime/compiler/ast"
+	"github.com/jaqx0r/mtail/internal/runtime/compiler/errors"
+	"github.com/jaqx0r/mtail/internal/runtime/compiler/parser"
+	"github.com/jaqx0r/mtail/internal/runtime/compiler/position"
+	"github.com/jaqx0r/mtail/internal/runtime/compiler/symbol"
+	"github.com/jaqx0r/mtail/internal/runtime/compiler/types"
 )
 
 // codegen represents a code generator.
@@ -38,7 +38,7 @@ func CodeGen(name string, n ast.Node) (*code.Object, error) {
 	_ = ast.Walk(c, n)
 	c.writeJumps()
 	if len(c.errors) > 0 {
-		return nil, c.errors
+		return nil, &c.errors
 	}
 	return &c.obj, nil
 }
@@ -134,16 +134,16 @@ func (c *codegen) VisitBefore(node ast.Node) (ast.Visitor, ast.Node) {
 			if n.Buckets[0] > 0 {
 				m.Buckets = append(m.Buckets, datum.Range{0, n.Buckets[0]})
 			}
-			min := n.Buckets[0]
-			for _, max := range n.Buckets[1:] {
-				if max <= min {
+			lo := n.Buckets[0]
+			for _, hi := range n.Buckets[1:] {
+				if hi <= lo {
 					c.errorf(n.Pos(), "buckets boundaries must be sorted")
 					return nil, n
 				}
-				m.Buckets = append(m.Buckets, datum.Range{min, max})
-				min = max
+				m.Buckets = append(m.Buckets, datum.Range{lo, hi})
+				lo = hi
 			}
-			m.Buckets = append(m.Buckets, datum.Range{min, math.Inf(+1)})
+			m.Buckets = append(m.Buckets, datum.Range{lo, math.Inf(+1)})
 
 			if len(n.Keys) == 0 {
 				// Calling GetDatum here causes the storage to be allocated.
