@@ -12,9 +12,9 @@ import (
 	"flag"
 	"fmt"
 
-	"github.com/google/mtail/internal/logline"
-	"github.com/google/mtail/internal/runtime/compiler"
-	"github.com/google/mtail/internal/runtime/vm"
+	"github.com/jaqx0r/mtail/internal/logline"
+	"github.com/jaqx0r/mtail/internal/runtime/compiler"
+	"github.com/jaqx0r/mtail/internal/runtime/vm"
 )
 
 // U+2424 SYMBOL FOR NEWLINE
