@@ -20,10 +20,10 @@ import (
 	"time"
 
 	"github.com/golang/glog"
-	"github.com/google/mtail/internal/logline"
-	"github.com/google/mtail/internal/metrics"
-	"github.com/google/mtail/internal/runtime/compiler"
-	"github.com/google/mtail/internal/runtime/vm"
+	"github.com/jaqx0r/mtail/internal/logline"
+	"github.com/jaqx0r/mtail/internal/metrics"
+	"github.com/jaqx0r/mtail/internal/runtime/compiler"
+	"github.com/jaqx0r/mtail/internal/runtime/vm"
 	"github.com/pkg/errors"
 	"github.com/prometheus/client_golang/prometheus"
 )
