@@ -13,10 +13,10 @@ import (
 	"testing"
 
 	"github.com/golang/glog"
-	"github.com/google/mtail/internal/logline"
-	"github.com/google/mtail/internal/tailer/logstream"
-	"github.com/google/mtail/internal/testutil"
-	"github.com/google/mtail/internal/waker"
+	"github.com/jaqx0r/mtail/internal/logline"
+	"github.com/jaqx0r/mtail/internal/tailer/logstream"
+	"github.com/jaqx0r/mtail/internal/testutil"
+	"github.com/jaqx0r/mtail/internal/waker"
 )
 
 // TestFileStreamRotation is a unix-specific test because on Windows, files cannot be removed
